## Release 2021-09-08 0.2.1

- Changed auth.git to auth.global [3f2fd7d](git@github.com:berttejeda/bert.bill/commit/3f2fd7d3aef6cb2bae3c59bdad6ee4d790ad0e32)
- Use hardcoded gui_dirname for setup [365db34](git@github.com:berttejeda/bert.bill/commit/365db34837049f2d997ae324c805e2748cb6b4e0)
- Fix reference to gui files [427807c](git@github.com:berttejeda/bert.bill/commit/427807cdac0ac886334f5675a8d894c0290cebe3)

## Release 2021-09-06 0.2.0

- Incorporated gui files for pip distribution [7e5deb4](git@github.com:berttejeda/bert.bill/commit/7e5deb4b9868543652d274bb8b3551f59214124f)
- Set required Python version to 3.7+ [dd5bd6f](git@github.com:berttejeda/bert.bill/commit/dd5bd6fff7283aa5b4116afc0b45e90697103cec)
- Cleaned up node scripts [ebbbede](git@github.com:berttejeda/bert.bill/commit/ebbbedeeaec10940c77565ad079929f18ef63686)
- Fixed data files path for pip installer [bb24717](git@github.com:berttejeda/bert.bill/commit/bb24717a637a0ec7c5dccaa9d541b106358a2b04)
- Gui directory name is set in defaults [2bc1cff](git@github.com:berttejeda/bert.bill/commit/2bc1cffb06cde7f4ae06cc21f9e50e9d5ee6683e)
- Fixed duplicate script calls when using run-script-os [e196296](git@github.com:berttejeda/bert.bill/commit/e1962960fac4e19b0877949962914676177726ac)
- Renamed ssl_verify param to verify_tls [ab9b058](git@github.com:berttejeda/bert.bill/commit/ab9b058c61f59ad3593efb029dd6ea6b6f3e1a7c)
- Adjusted node scripts for build actions [00033f9](git@github.com:berttejeda/bert.bill/commit/00033f97fd38916e42580db2b5490e150058f363)
- Added default, built-in settings for when config not found [1e79cee](git@github.com:berttejeda/bert.bill/commit/1e79cee0b93141c0f584a5cccb776df1d703631e)
- Added ssl_verify flag [aaa7743](git@github.com:berttejeda/bert.bill/commit/aaa7743c454ac4ea6a4c02f8dc85b8a763fc0419)
- Fixed debug logging [f666878](git@github.com:berttejeda/bert.bill/commit/f6668784bf0cfd98916680d8caabe8a57fdf404a)
- Proper styling for LessonLoader error messages [5f5c4f4](git@github.com:berttejeda/bert.bill/commit/5f5c4f476eb181091b576cbffe22ead15797b387)
- Set fail on errors for bertdotwebadapter [66315a7](git@github.com:berttejeda/bert.bill/commit/66315a7a75c87cf3d597c269819fdd7256ba1e89)

## Release 2021-08-31 0.1.1

- Initial Commit [f144b1c](git@github.com:berttejeda/bert.bill/commit/f144b1c993411a1e6cfa66b186d926c725db892d)
